**********
References
**********

.. [Boyd04] `Convex Optimization
   <https://web.stanford.edu/~boyd/cvxbook/bv_cvxbook.pdf>`_, Stephen Boyd and
   Lieven Vandenberghe, Cambridge University Press, 2004.

.. [Bretl08] *Testing Static Equilibrium for Legged Robots*, T. Bretl and S.
   Lall, IEEE Transactions on Robotics, vol. 24, no. 4, pp. 794-807, August
   2008.
